@@ -34,12 +34,3 @@ test_that("add_p works well", {
     NA
   )
 })
-
-
-test_that("add_p creates errors named list passed for test", {
-  expect_error(
-    tbl_summary(mtcars, by = am) %>%
-      add_p(test = list(cyl = "t.test")),
-    "*"
-  )
-})
